import click

from cythereal_cli.api_client import configure_api
from cythereal_cli.upload import upload

CONTEXT_SETTINGS = dict(
    help_option_names=['-h', '--help']
)


@click.group(context_settings=CONTEXT_SETTINGS)
@click.option('-k', '--key', 'api_key', envvar='MAGIC_API_KEY',
              prompt="MAGIC API Key",
              help="API Key for the MAGIC API. Can be set using the environment variable MAGIC_API_KEY")
def main(api_key):
    configure_api(api_key)

# Add subcommands
main.add_command(upload)


if __name__ == '__main__':
    main()



# coding: utf-8

"""
    Cythereal MAGIC API

     The API for accessing Cythereal MAGIC products and services.  # API Clients  We provide clients in several languages for accessing the MAGIC API. https://bitbucket.org/cythereal/magic-clients  These clients are provided to make integration of the MAGIC API into your existing applications as easy as possible.  If you want to use a language that is not currently supported, please contact us at support@cythereal.com and we will be glad to help.  # Example Inputs  Here are some example inputs that can be used for testing the service:  * Binary SHA1: `ff9790d7902fea4c910b182f6e0b00221a40d616`   * Can be used for `file_hash` parameters. * Procedure RVA: `0x1000`   * Use with the above SHA1 for `proc_rva` parameters.   # API Conventions  Properties MUST be named using `snake_case`.  This API is inspired by the [google json style guide](https://google.github.io/styleguide/jsoncstyleguide.xml). Any questions about conventions not documented here should be addressed by this style guide.  **All responses** MUST be of type `APIResponse` and contain the following fields:  * `api_version` |  The current api version * `success` | Boolean value indicating if the operation succeeded. * `code` | Status code. Typically corresponds to the HTTP status code.  * `message` | A human readable message providing more details about the operation. Can be null or empty.  **Successful operations** MUST return a `SuccessResponse`, which extends `APIResponse` by adding:  * `data` | Properties containing the response object. * `success` | MUST equal True  When returning objects from a successful response, the `data` object SHOULD contain a property named after the requested object type. For example, the `/matches` endpoint should return a response object with `data.matches`. This property SHOULD  contain a list of the returned objects. For the `/matches` endpoint, the `data.matches` property contains a list of MagicMatch objects. See the `/matches` endpoint documentation for an example.  **Failed Operations** MUST return an `ErrorResponse`, which extends `APIResponse` by adding:  * `errors` | Array of error objects. An error object contains the following properties:     * `ErrorObject.reason` | Unique identifier for this error. Example: \"FileNotFoundError\".     * `ErrorObject.message`| Human readable error message. * `success` | MUST equal False.   # noqa: E501

    OpenAPI spec version: 1
    Contact: support@cythereal.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cythereal_magic.api_client import ApiClient


class AlphaApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_campaign_info(self, campaign_id, **kwargs):  # noqa: E501
        """List available information for the campaign id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_campaign_info(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str campaign_id: The ID of a campaign. Equal to the binary_id of a random binary in the campaign. (required)
        :return: CampaignInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_campaign_info_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_campaign_info_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def get_campaign_info_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """List available information for the campaign id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_campaign_info_with_http_info(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str campaign_id: The ID of a campaign. Equal to the binary_id of a random binary in the campaign. (required)
        :return: CampaignInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_campaign_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `get_campaign_info`")  # noqa: E501

        if 'campaign_id' in params and not re.search('[a-fA-F0-9]{40}', params['campaign_id']):  # noqa: E501
            raise ValueError("Invalid value for parameter `campaign_id` when calling `get_campaign_info`, must conform to the pattern `/[a-fA-F0-9]{40}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaign_id'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/campaigns/{campaign_id}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CampaignInfoResponse',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_campaign_members(self, campaign_id, **kwargs):  # noqa: E501
        """Members of the campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_campaign_members(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str campaign_id: The ID of a campaign. Equal to the binary_id of a random binary in the campaign. (required)
        :return: CampaignMembersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_campaign_members_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_campaign_members_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def get_campaign_members_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Members of the campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_campaign_members_with_http_info(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str campaign_id: The ID of a campaign. Equal to the binary_id of a random binary in the campaign. (required)
        :return: CampaignMembersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_campaign_members" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `get_campaign_members`")  # noqa: E501

        if 'campaign_id' in params and not re.search('[a-fA-F0-9]{40}', params['campaign_id']):  # noqa: E501
            raise ValueError("Invalid value for parameter `campaign_id` when calling `get_campaign_members`, must conform to the pattern `/[a-fA-F0-9]{40}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaign_id'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/campaigns/{campaign_id}/members', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CampaignMembersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_campaign_procedures(self, campaign_id, **kwargs):  # noqa: E501
        """Report on binaries and procedures in the campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_campaign_procedures(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str campaign_id: The ID of a campaign. Equal to the binary_id of a random binary in the campaign. (required)
        :return: CampaignProceduresResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_campaign_procedures_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_campaign_procedures_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def get_campaign_procedures_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Report on binaries and procedures in the campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_campaign_procedures_with_http_info(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str campaign_id: The ID of a campaign. Equal to the binary_id of a random binary in the campaign. (required)
        :return: CampaignProceduresResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_campaign_procedures" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `get_campaign_procedures`")  # noqa: E501

        if 'campaign_id' in params and not re.search('[a-fA-F0-9]{40}', params['campaign_id']):  # noqa: E501
            raise ValueError("Invalid value for parameter `campaign_id` when calling `get_campaign_procedures`, must conform to the pattern `/[a-fA-F0-9]{40}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaign_id'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/campaigns/{campaign_id}/procedures', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CampaignProceduresResponse',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_campaign_yara(self, campaign_id, **kwargs):  # noqa: E501
        """Yara rule for detecting binary.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_campaign_yara(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str campaign_id: The ID of a campaign. Equal to the binary_id of a random binary in the campaign. (required)
        :param bool unpacked: If true, get yara rule for unpacked binaries instead of the originally uploaded binaries. 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_campaign_yara_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_campaign_yara_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def get_campaign_yara_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Yara rule for detecting binary.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_campaign_yara_with_http_info(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str campaign_id: The ID of a campaign. Equal to the binary_id of a random binary in the campaign. (required)
        :param bool unpacked: If true, get yara rule for unpacked binaries instead of the originally uploaded binaries. 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'unpacked']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_campaign_yara" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `get_campaign_yara`")  # noqa: E501

        if 'campaign_id' in params and not re.search('[a-fA-F0-9]{40}', params['campaign_id']):  # noqa: E501
            raise ValueError("Invalid value for parameter `campaign_id` when calling `get_campaign_yara`, must conform to the pattern `/[a-fA-F0-9]{40}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaign_id'] = params['campaign_id']  # noqa: E501

        query_params = []
        if 'unpacked' in params:
            query_params.append(('unpacked', params['unpacked']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/campaigns/{campaign_id}/yara', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file_status(self, file_hash, **kwargs):  # noqa: E501
        """Get processing status of the file.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_file_status(file_hash, async=True)
        >>> result = thread.get()

        :param async bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: FileStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_file_status_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.get_file_status_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    def get_file_status_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Get processing status of the file.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_file_status_with_http_info(file_hash, async=True)
        >>> result = thread.get()

        :param async bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: FileStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_file_status`")  # noqa: E501

        if 'file_hash' in params and not re.search('[a-fA-F0-9]{40}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_file_status`, must conform to the pattern `/[a-fA-F0-9]{40}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/files/{file_hash}/status/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    Cythereal MAGIC API

     The API for accessing Cythereal MAGIC products and services.  # API Clients  We provide clients in several languages for accessing the MAGIC API. https://bitbucket.org/cythereal/magic-clients  These clients are provided to make integration of the MAGIC API into your existing applications as easy as possible.  If you want to use a language that is not currently supported, please contact us at support@cythereal.com and we will be glad to help.  # Example Inputs  Here are some example inputs that can be used for testing the service:  * Binary SHA1: `ff9790d7902fea4c910b182f6e0b00221a40d616`   * Can be used for `file_hash` parameters. * Procedure RVA: `0x1000`   * Use with the above SHA1 for `proc_rva` parameters.   # API Conventions  Properties MUST be named using `snake_case`.  This API is inspired by the [google json style guide](https://google.github.io/styleguide/jsoncstyleguide.xml). Any questions about conventions not documented here should be addressed by this style guide.  **All responses** MUST be of type `APIResponse` and contain the following fields:  * `api_version` |  The current api version * `success` | Boolean value indicating if the operation succeeded. * `code` | Status code. Typically corresponds to the HTTP status code.  * `message` | A human readable message providing more details about the operation. Can be null or empty.  **Successful operations** MUST return a `SuccessResponse`, which extends `APIResponse` by adding:  * `data` | Properties containing the response object. * `success` | MUST equal True  When returning objects from a successful response, the `data` object SHOULD contain a property named after the requested object type. For example, the `/matches` endpoint should return a response object with `data.matches`. This property SHOULD  contain a list of the returned objects. For the `/matches` endpoint, the `data.matches` property contains a list of MagicMatch objects. See the `/matches` endpoint documentation for an example.  **Failed Operations** MUST return an `ErrorResponse`, which extends `APIResponse` by adding:  * `errors` | Array of error objects. An error object contains the following properties:     * `ErrorObject.reason` | Unique identifier for this error. Example: \"FileNotFoundError\".     * `ErrorObject.message`| Human readable error message. * `success` | MUST equal False.   # noqa: E501

    OpenAPI spec version: 1
    Contact: support@cythereal.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from cythereal_magic.models.analysis_status import AnalysisStatus
from cythereal_magic.models.api_response import ApiResponse
from cythereal_magic.models.binary_genomics import BinaryGenomics
from cythereal_magic.models.binary_similarity import BinarySimilarity
from cythereal_magic.models.binary_similarity_binaries import BinarySimilarityBinaries
from cythereal_magic.models.block_genomics import BlockGenomics
from cythereal_magic.models.campaign_info_response_data import CampaignInfoResponseData
from cythereal_magic.models.campaign_info_response_links import CampaignInfoResponseLinks
from cythereal_magic.models.campaign_members_response_data import CampaignMembersResponseData
from cythereal_magic.models.campaign_members_response_data_members import CampaignMembersResponseDataMembers
from cythereal_magic.models.campaign_procedures_response_data import CampaignProceduresResponseData
from cythereal_magic.models.campaign_procedures_response_data_procedures import CampaignProceduresResponseDataProcedures
from cythereal_magic.models.child_info import ChildInfo
from cythereal_magic.models.control_flow_graph import ControlFlowGraph
from cythereal_magic.models.file_info import FileInfo
from cythereal_magic.models.file_status import FileStatus
from cythereal_magic.models.file_upload_response_data import FileUploadResponseData
from cythereal_magic.models.magic_categories import MagicCategories
from cythereal_magic.models.magic_category import MagicCategory
from cythereal_magic.models.magic_category_list import MagicCategoryList
from cythereal_magic.models.magic_label import MagicLabel
from cythereal_magic.models.magic_labels import MagicLabels
from cythereal_magic.models.magic_matches import MagicMatches
from cythereal_magic.models.magic_matches_match_subtypes import MagicMatchesMatchSubtypes
from cythereal_magic.models.magic_matches_matches import MagicMatchesMatches
from cythereal_magic.models.magic_report import MagicReport
from cythereal_magic.models.magic_report_detection_stats import MagicReportDetectionStats
from cythereal_magic.models.owned_files_list import OwnedFilesList
from cythereal_magic.models.owned_files_list_files import OwnedFilesListFiles
from cythereal_magic.models.procedure_genomics import ProcedureGenomics
from cythereal_magic.models.procedure_similarity import ProcedureSimilarity
from cythereal_magic.models.procedure_similarity_procedures import ProcedureSimilarityProcedures
from cythereal_magic.models.error_response import ErrorResponse
from cythereal_magic.models.success_response import SuccessResponse
from cythereal_magic.models.binary_genomics_response import BinaryGenomicsResponse
from cythereal_magic.models.binary_similarity_response import BinarySimilarityResponse
from cythereal_magic.models.campaign_info_response import CampaignInfoResponse
from cythereal_magic.models.campaign_members_response import CampaignMembersResponse
from cythereal_magic.models.campaign_procedures_response import CampaignProceduresResponse
from cythereal_magic.models.file_info_response import FileInfoResponse
from cythereal_magic.models.file_status_response import FileStatusResponse
from cythereal_magic.models.file_upload_response import FileUploadResponse
from cythereal_magic.models.magic_categories_response import MagicCategoriesResponse
from cythereal_magic.models.magic_labels_response import MagicLabelsResponse
from cythereal_magic.models.magic_matches_response import MagicMatchesResponse
from cythereal_magic.models.magic_report_response import MagicReportResponse
from cythereal_magic.models.owned_files_list_response import OwnedFilesListResponse
from cythereal_magic.models.procedure_genomics_response import ProcedureGenomicsResponse
from cythereal_magic.models.procedure_similarity_response import ProcedureSimilarityResponse



# coding: utf-8

"""
    Cythereal MAGIC API

     The API for accessing Cythereal MAGIC products and services.  # API Clients  We provide clients in several languages for accessing the MAGIC API. https://bitbucket.org/cythereal/magic-clients  These clients are provided to make integration of the MAGIC API into your existing applications as easy as possible.  If you want to use a language that is not currently supported, please contact us at support@cythereal.com and we will be glad to help.  # Example Inputs  Here are some example inputs that can be used for testing the service:  * Binary SHA1: `ff9790d7902fea4c910b182f6e0b00221a40d616`   * Can be used for `file_hash` parameters. * Procedure RVA: `0x1000`   * Use with the above SHA1 for `proc_rva` parameters.   # API Conventions  Properties MUST be named using `snake_case`.  This API is inspired by the [google json style guide](https://google.github.io/styleguide/jsoncstyleguide.xml). Any questions about conventions not documented here should be addressed by this style guide.  **All responses** MUST be of type `APIResponse` and contain the following fields:  * `api_version` |  The current api version * `success` | Boolean value indicating if the operation succeeded. * `code` | Status code. Typically corresponds to the HTTP status code.  * `message` | A human readable message providing more details about the operation. Can be null or empty.  **Successful operations** MUST return a `SuccessResponse`, which extends `APIResponse` by adding:  * `data` | Properties containing the response object. * `success` | MUST equal True  When returning objects from a successful response, the `data` object SHOULD contain a property named after the requested object type. For example, the `/matches` endpoint should return a response object with `data.matches`. This property SHOULD  contain a list of the returned objects. For the `/matches` endpoint, the `data.matches` property contains a list of MagicMatch objects. See the `/matches` endpoint documentation for an example.  **Failed Operations** MUST return an `ErrorResponse`, which extends `APIResponse` by adding:  * `errors` | Array of error objects. An error object contains the following properties:     * `ErrorObject.reason` | Unique identifier for this error. Example: \"FileNotFoundError\".     * `ErrorObject.message`| Human readable error message. * `success` | MUST equal False.   # noqa: E501

    OpenAPI spec version: 1
    Contact: support@cythereal.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cythereal_magic.models.analysis_status import AnalysisStatus  # noqa: F401,E501


class FileStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sha1': 'str',
        'status': 'str',
        'unix_filetype': 'str',
        'first_upload': 'datetime',
        'analysis': 'list[AnalysisStatus]'
    }

    attribute_map = {
        'sha1': 'sha1',
        'status': 'status',
        'unix_filetype': 'unix_filetype',
        'first_upload': 'first_upload',
        'analysis': 'analysis'
    }

    def __init__(self, sha1=None, status=None, unix_filetype=None, first_upload=None, analysis=None):  # noqa: E501
        """FileStatus - a model defined in Swagger"""  # noqa: E501

        self._sha1 = None
        self._status = None
        self._unix_filetype = None
        self._first_upload = None
        self._analysis = None
        self.discriminator = None

        self.sha1 = sha1
        self.status = status
        if unix_filetype is not None:
            self.unix_filetype = unix_filetype
        if first_upload is not None:
            self.first_upload = first_upload
        if analysis is not None:
            self.analysis = analysis

    @property
    def sha1(self):
        """Gets the sha1 of this FileStatus.  # noqa: E501

        A SHA1 cryptographic hash  # noqa: E501

        :return: The sha1 of this FileStatus.  # noqa: E501
        :rtype: str
        """
        return self._sha1

    @sha1.setter
    def sha1(self, sha1):
        """Sets the sha1 of this FileStatus.

        A SHA1 cryptographic hash  # noqa: E501

        :param sha1: The sha1 of this FileStatus.  # noqa: E501
        :type: str
        """
        if sha1 is None:
            raise ValueError("Invalid value for `sha1`, must not be `None`")  # noqa: E501
        if sha1 is not None and not re.search('[a-fA-F0-9]{40}', sha1):  # noqa: E501
            raise ValueError("Invalid value for `sha1`, must be a follow pattern or equal to `/[a-fA-F0-9]{40}/`")  # noqa: E501

        self._sha1 = sha1

    @property
    def status(self):
        """Gets the status of this FileStatus.  # noqa: E501

        One of: - **pending**: Processing has not started yet. - **in progress**: Processing has begun, but not all analysis are complete. - **success**: All analysis successfully completed. - **error**: At least one analysis returned an error. * **none**: File is not a file type that is analyzed.   # noqa: E501

        :return: The status of this FileStatus.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this FileStatus.

        One of: - **pending**: Processing has not started yet. - **in progress**: Processing has begun, but not all analysis are complete. - **success**: All analysis successfully completed. - **error**: At least one analysis returned an error. * **none**: File is not a file type that is analyzed.   # noqa: E501

        :param status: The status of this FileStatus.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["pending", "in progress", "success", "error", "none"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def unix_filetype(self):
        """Gets the unix_filetype of this FileStatus.  # noqa: E501

        The unix filetype of the file  # noqa: E501

        :return: The unix_filetype of this FileStatus.  # noqa: E501
        :rtype: str
        """
        return self._unix_filetype

    @unix_filetype.setter
    def unix_filetype(self, unix_filetype):
        """Sets the unix_filetype of this FileStatus.

        The unix filetype of the file  # noqa: E501

        :param unix_filetype: The unix_filetype of this FileStatus.  # noqa: E501
        :type: str
        """

        self._unix_filetype = unix_filetype

    @property
    def first_upload(self):
        """Gets the first_upload of this FileStatus.  # noqa: E501

        The timestamp of the original upload.  # noqa: E501

        :return: The first_upload of this FileStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._first_upload

    @first_upload.setter
    def first_upload(self, first_upload):
        """Sets the first_upload of this FileStatus.

        The timestamp of the original upload.  # noqa: E501

        :param first_upload: The first_upload of this FileStatus.  # noqa: E501
        :type: datetime
        """

        self._first_upload = first_upload

    @property
    def analysis(self):
        """Gets the analysis of this FileStatus.  # noqa: E501

        Status of each individual analysis. The exact contents of this list is not guaranteed and will change over time as we add or modify the analyses that we support.  Not every file will go through every analysis. For example, a zip file goes through archive extraction only.  The (potentially incomplete) list of analysis types: - **genomics**: Extracting the genomics from the binary. - **matches**: Finding the MAGIC matches of a binary. - **labels**: Assigning labels to the binary. - **campaigns**: Adding binaries to a campaign. - **unpacking**: Unpacking the binary and analyzing the unpacked binary. - **archive_extraction**: Extract files from an archive (e.g., unzip a zip file).   # noqa: E501

        :return: The analysis of this FileStatus.  # noqa: E501
        :rtype: list[AnalysisStatus]
        """
        return self._analysis

    @analysis.setter
    def analysis(self, analysis):
        """Sets the analysis of this FileStatus.

        Status of each individual analysis. The exact contents of this list is not guaranteed and will change over time as we add or modify the analyses that we support.  Not every file will go through every analysis. For example, a zip file goes through archive extraction only.  The (potentially incomplete) list of analysis types: - **genomics**: Extracting the genomics from the binary. - **matches**: Finding the MAGIC matches of a binary. - **labels**: Assigning labels to the binary. - **campaigns**: Adding binaries to a campaign. - **unpacking**: Unpacking the binary and analyzing the unpacked binary. - **archive_extraction**: Extract files from an archive (e.g., unzip a zip file).   # noqa: E501

        :param analysis: The analysis of this FileStatus.  # noqa: E501
        :type: list[AnalysisStatus]
        """

        self._analysis = analysis

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
